@@ -151,28 +151,29 @@ __all__ = (
 AccessConfigurationTypeDef = TypedDict(
     "AccessConfigurationTypeDef",
     {
-        "AccessType": NotRequired[AccessTypeType],
-        "SecretsManagerAccessTokenConfiguration": NotRequired[
-            "SecretsManagerAccessTokenConfigurationTypeDef"
-        ],
+        "AccessType": AccessTypeType,
+        "SecretsManagerAccessTokenConfiguration": "SecretsManagerAccessTokenConfigurationTypeDef",
     },
+    total=False,
 )
 
 AdBreakTypeDef = TypedDict(
     "AdBreakTypeDef",
     {
-        "MessageType": NotRequired[Literal["SPLICE_INSERT"]],
-        "OffsetMillis": NotRequired[int],
-        "Slate": NotRequired["SlateSourceTypeDef"],
-        "SpliceInsertMessage": NotRequired["SpliceInsertMessageTypeDef"],
+        "MessageType": Literal["SPLICE_INSERT"],
+        "OffsetMillis": int,
+        "Slate": "SlateSourceTypeDef",
+        "SpliceInsertMessage": "SpliceInsertMessageTypeDef",
     },
+    total=False,
 )
 
 AdMarkerPassthroughTypeDef = TypedDict(
     "AdMarkerPassthroughTypeDef",
     {
-        "Enabled": NotRequired[bool],
+        "Enabled": bool,
     },
+    total=False,
 )
 
 AlertTypeDef = TypedDict(
@@ -197,41 +198,55 @@ AvailMatchingCriteriaTypeDef = TypedDict(
 AvailSuppressionTypeDef = TypedDict(
     "AvailSuppressionTypeDef",
     {
-        "Mode": NotRequired[ModeType],
-        "Value": NotRequired[str],
+        "Mode": ModeType,
+        "Value": str,
     },
+    total=False,
 )
 
 BumperTypeDef = TypedDict(
     "BumperTypeDef",
     {
-        "EndUrl": NotRequired[str],
-        "StartUrl": NotRequired[str],
+        "EndUrl": str,
+        "StartUrl": str,
     },
+    total=False,
 )
 
 CdnConfigurationTypeDef = TypedDict(
     "CdnConfigurationTypeDef",
     {
-        "AdSegmentUrlPrefix": NotRequired[str],
-        "ContentSegmentUrlPrefix": NotRequired[str],
+        "AdSegmentUrlPrefix": str,
+        "ContentSegmentUrlPrefix": str,
     },
+    total=False,
 )
 
-ChannelTypeDef = TypedDict(
-    "ChannelTypeDef",
+_RequiredChannelTypeDef = TypedDict(
+    "_RequiredChannelTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
         "ChannelState": str,
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
-        "CreationTime": NotRequired[datetime],
-        "FillerSlate": NotRequired["SlateSourceTypeDef"],
-        "LastModifiedTime": NotRequired[datetime],
-        "Tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalChannelTypeDef = TypedDict(
+    "_OptionalChannelTypeDef",
+    {
+        "CreationTime": datetime,
+        "FillerSlate": "SlateSourceTypeDef",
+        "LastModifiedTime": datetime,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
+    pass
+
 
 ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef = TypedDict(
     "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
@@ -250,16 +265,29 @@ ConfigureLogsForPlaybackConfigurationResponseTypeDef = TypedDict(
     },
 )
 
-CreateChannelRequestRequestTypeDef = TypedDict(
-    "CreateChannelRequestRequestTypeDef",
+_RequiredCreateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Outputs": Sequence["RequestOutputItemTypeDef"],
         "PlaybackMode": PlaybackModeType,
-        "FillerSlate": NotRequired["SlateSourceTypeDef"],
-        "Tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelRequestRequestTypeDef",
+    {
+        "FillerSlate": "SlateSourceTypeDef",
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateChannelRequestRequestTypeDef(
+    _RequiredCreateChannelRequestRequestTypeDef, _OptionalCreateChannelRequestRequestTypeDef
+):
+    pass
+
 
 CreateChannelResponseTypeDef = TypedDict(
     "CreateChannelResponseTypeDef",
@@ -277,16 +305,30 @@ CreateChannelResponseTypeDef = TypedDict(
     },
 )
 
-CreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
-    "CreatePrefetchScheduleRequestRequestTypeDef",
+_RequiredCreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePrefetchScheduleRequestRequestTypeDef",
     {
         "Consumption": "PrefetchConsumptionTypeDef",
         "Name": str,
         "PlaybackConfigurationName": str,
         "Retrieval": "PrefetchRetrievalTypeDef",
-        "StreamId": NotRequired[str],
     },
 )
+_OptionalCreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePrefetchScheduleRequestRequestTypeDef",
+    {
+        "StreamId": str,
+    },
+    total=False,
+)
+
+
+class CreatePrefetchScheduleRequestRequestTypeDef(
+    _RequiredCreatePrefetchScheduleRequestRequestTypeDef,
+    _OptionalCreatePrefetchScheduleRequestRequestTypeDef,
+):
+    pass
+
 
 CreatePrefetchScheduleResponseTypeDef = TypedDict(
     "CreatePrefetchScheduleResponseTypeDef",
@@ -301,17 +343,30 @@ CreatePrefetchScheduleResponseTypeDef = TypedDict(
     },
 )
 
-CreateProgramRequestRequestTypeDef = TypedDict(
-    "CreateProgramRequestRequestTypeDef",
+_RequiredCreateProgramRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProgramRequestRequestTypeDef",
     {
         "ChannelName": str,
         "ProgramName": str,
         "ScheduleConfiguration": "ScheduleConfigurationTypeDef",
         "SourceLocationName": str,
         "VodSourceName": str,
-        "AdBreaks": NotRequired[Sequence["AdBreakTypeDef"]],
     },
 )
+_OptionalCreateProgramRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProgramRequestRequestTypeDef",
+    {
+        "AdBreaks": Sequence["AdBreakTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateProgramRequestRequestTypeDef(
+    _RequiredCreateProgramRequestRequestTypeDef, _OptionalCreateProgramRequestRequestTypeDef
+):
+    pass
+
 
 CreateProgramResponseTypeDef = TypedDict(
     "CreateProgramResponseTypeDef",
@@ -328,21 +383,31 @@ CreateProgramResponseTypeDef = TypedDict(
     },
 )
 
-CreateSourceLocationRequestRequestTypeDef = TypedDict(
-    "CreateSourceLocationRequestRequestTypeDef",
+_RequiredCreateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSourceLocationRequestRequestTypeDef",
     {
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
-        "AccessConfiguration": NotRequired["AccessConfigurationTypeDef"],
-        "DefaultSegmentDeliveryConfiguration": NotRequired[
-            "DefaultSegmentDeliveryConfigurationTypeDef"
-        ],
-        "SegmentDeliveryConfigurations": NotRequired[
-            Sequence["SegmentDeliveryConfigurationTypeDef"]
-        ],
-        "Tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSourceLocationRequestRequestTypeDef",
+    {
+        "AccessConfiguration": "AccessConfigurationTypeDef",
+        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
+        "SegmentDeliveryConfigurations": Sequence["SegmentDeliveryConfigurationTypeDef"],
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateSourceLocationRequestRequestTypeDef(
+    _RequiredCreateSourceLocationRequestRequestTypeDef,
+    _OptionalCreateSourceLocationRequestRequestTypeDef,
+):
+    pass
+
 
 CreateSourceLocationResponseTypeDef = TypedDict(
     "CreateSourceLocationResponseTypeDef",
@@ -360,15 +425,28 @@ CreateSourceLocationResponseTypeDef = TypedDict(
     },
 )
 
-CreateVodSourceRequestRequestTypeDef = TypedDict(
-    "CreateVodSourceRequestRequestTypeDef",
+_RequiredCreateVodSourceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateVodSourceRequestRequestTypeDef",
     {
         "HttpPackageConfigurations": Sequence["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
         "VodSourceName": str,
-        "Tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateVodSourceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateVodSourceRequestRequestTypeDef",
+    {
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateVodSourceRequestRequestTypeDef(
+    _RequiredCreateVodSourceRequestRequestTypeDef, _OptionalCreateVodSourceRequestRequestTypeDef
+):
+    pass
+
 
 CreateVodSourceResponseTypeDef = TypedDict(
     "CreateVodSourceResponseTypeDef",
@@ -387,35 +465,39 @@ CreateVodSourceResponseTypeDef = TypedDict(
 DashConfigurationForPutTypeDef = TypedDict(
     "DashConfigurationForPutTypeDef",
     {
-        "MpdLocation": NotRequired[str],
-        "OriginManifestType": NotRequired[OriginManifestTypeType],
+        "MpdLocation": str,
+        "OriginManifestType": OriginManifestTypeType,
     },
+    total=False,
 )
 
 DashConfigurationTypeDef = TypedDict(
     "DashConfigurationTypeDef",
     {
-        "ManifestEndpointPrefix": NotRequired[str],
-        "MpdLocation": NotRequired[str],
-        "OriginManifestType": NotRequired[OriginManifestTypeType],
+        "ManifestEndpointPrefix": str,
+        "MpdLocation": str,
+        "OriginManifestType": OriginManifestTypeType,
     },
+    total=False,
 )
 
 DashPlaylistSettingsTypeDef = TypedDict(
     "DashPlaylistSettingsTypeDef",
     {
-        "ManifestWindowSeconds": NotRequired[int],
-        "MinBufferTimeSeconds": NotRequired[int],
-        "MinUpdatePeriodSeconds": NotRequired[int],
-        "SuggestedPresentationDelaySeconds": NotRequired[int],
+        "ManifestWindowSeconds": int,
+        "MinBufferTimeSeconds": int,
+        "MinUpdatePeriodSeconds": int,
+        "SuggestedPresentationDelaySeconds": int,
     },
+    total=False,
 )
 
 DefaultSegmentDeliveryConfigurationTypeDef = TypedDict(
     "DefaultSegmentDeliveryConfigurationTypeDef",
     {
-        "BaseUrl": NotRequired[str],
+        "BaseUrl": str,
     },
+    total=False,
 )
 
 DeleteChannelPolicyRequestRequestTypeDef = TypedDict(
@@ -576,24 +658,52 @@ GetChannelPolicyResponseTypeDef = TypedDict(
     },
 )
 
-GetChannelScheduleRequestGetChannelSchedulePaginateTypeDef = TypedDict(
-    "GetChannelScheduleRequestGetChannelSchedulePaginateTypeDef",
+_RequiredGetChannelScheduleRequestGetChannelSchedulePaginateTypeDef = TypedDict(
+    "_RequiredGetChannelScheduleRequestGetChannelSchedulePaginateTypeDef",
     {
         "ChannelName": str,
-        "DurationMinutes": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalGetChannelScheduleRequestGetChannelSchedulePaginateTypeDef = TypedDict(
+    "_OptionalGetChannelScheduleRequestGetChannelSchedulePaginateTypeDef",
+    {
+        "DurationMinutes": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-GetChannelScheduleRequestRequestTypeDef = TypedDict(
-    "GetChannelScheduleRequestRequestTypeDef",
+
+class GetChannelScheduleRequestGetChannelSchedulePaginateTypeDef(
+    _RequiredGetChannelScheduleRequestGetChannelSchedulePaginateTypeDef,
+    _OptionalGetChannelScheduleRequestGetChannelSchedulePaginateTypeDef,
+):
+    pass
+
+
+_RequiredGetChannelScheduleRequestRequestTypeDef = TypedDict(
+    "_RequiredGetChannelScheduleRequestRequestTypeDef",
     {
         "ChannelName": str,
-        "DurationMinutes": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalGetChannelScheduleRequestRequestTypeDef = TypedDict(
+    "_OptionalGetChannelScheduleRequestRequestTypeDef",
+    {
+        "DurationMinutes": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class GetChannelScheduleRequestRequestTypeDef(
+    _RequiredGetChannelScheduleRequestRequestTypeDef,
+    _OptionalGetChannelScheduleRequestRequestTypeDef,
+):
+    pass
+
 
 GetChannelScheduleResponseTypeDef = TypedDict(
     "GetChannelScheduleResponseTypeDef",
@@ -661,15 +771,17 @@ GetPrefetchScheduleResponseTypeDef = TypedDict(
 HlsConfigurationTypeDef = TypedDict(
     "HlsConfigurationTypeDef",
     {
-        "ManifestEndpointPrefix": NotRequired[str],
+        "ManifestEndpointPrefix": str,
     },
+    total=False,
 )
 
 HlsPlaylistSettingsTypeDef = TypedDict(
     "HlsPlaylistSettingsTypeDef",
     {
-        "ManifestWindowSeconds": NotRequired[int],
+        "ManifestWindowSeconds": int,
     },
+    total=False,
 )
 
 HttpConfigurationTypeDef = TypedDict(
@@ -688,22 +800,49 @@ HttpPackageConfigurationTypeDef = TypedDict(
     },
 )
 
-ListAlertsRequestListAlertsPaginateTypeDef = TypedDict(
-    "ListAlertsRequestListAlertsPaginateTypeDef",
+_RequiredListAlertsRequestListAlertsPaginateTypeDef = TypedDict(
+    "_RequiredListAlertsRequestListAlertsPaginateTypeDef",
     {
         "ResourceArn": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListAlertsRequestListAlertsPaginateTypeDef = TypedDict(
+    "_OptionalListAlertsRequestListAlertsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListAlertsRequestRequestTypeDef = TypedDict(
-    "ListAlertsRequestRequestTypeDef",
+
+class ListAlertsRequestListAlertsPaginateTypeDef(
+    _RequiredListAlertsRequestListAlertsPaginateTypeDef,
+    _OptionalListAlertsRequestListAlertsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListAlertsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAlertsRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListAlertsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAlertsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAlertsRequestRequestTypeDef(
+    _RequiredListAlertsRequestRequestTypeDef, _OptionalListAlertsRequestRequestTypeDef
+):
+    pass
+
 
 ListAlertsResponseTypeDef = TypedDict(
     "ListAlertsResponseTypeDef",
@@ -717,16 +856,18 @@ ListAlertsResponseTypeDef = TypedDict(
 ListChannelsRequestListChannelsPaginateTypeDef = TypedDict(
     "ListChannelsRequestListChannelsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListChannelsRequestRequestTypeDef = TypedDict(
     "ListChannelsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListChannelsResponseTypeDef = TypedDict(
@@ -741,16 +882,18 @@ ListChannelsResponseTypeDef = TypedDict(
 ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef = TypedDict(
     "ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListPlaybackConfigurationsRequestRequestTypeDef = TypedDict(
     "ListPlaybackConfigurationsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListPlaybackConfigurationsResponseTypeDef = TypedDict(
@@ -762,24 +905,52 @@ ListPlaybackConfigurationsResponseTypeDef = TypedDict(
     },
 )
 
-ListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef = TypedDict(
-    "ListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef",
+_RequiredListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef = TypedDict(
+    "_RequiredListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef",
     {
         "PlaybackConfigurationName": str,
-        "StreamId": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef = TypedDict(
+    "_OptionalListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef",
+    {
+        "StreamId": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
-    "ListPrefetchSchedulesRequestRequestTypeDef",
+
+class ListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef(
+    _RequiredListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef,
+    _OptionalListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
+    "_RequiredListPrefetchSchedulesRequestRequestTypeDef",
     {
         "PlaybackConfigurationName": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "StreamId": NotRequired[str],
     },
 )
+_OptionalListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
+    "_OptionalListPrefetchSchedulesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "StreamId": str,
+    },
+    total=False,
+)
+
+
+class ListPrefetchSchedulesRequestRequestTypeDef(
+    _RequiredListPrefetchSchedulesRequestRequestTypeDef,
+    _OptionalListPrefetchSchedulesRequestRequestTypeDef,
+):
+    pass
+
 
 ListPrefetchSchedulesResponseTypeDef = TypedDict(
     "ListPrefetchSchedulesResponseTypeDef",
@@ -793,16 +964,18 @@ ListPrefetchSchedulesResponseTypeDef = TypedDict(
 ListSourceLocationsRequestListSourceLocationsPaginateTypeDef = TypedDict(
     "ListSourceLocationsRequestListSourceLocationsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListSourceLocationsRequestRequestTypeDef = TypedDict(
     "ListSourceLocationsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListSourceLocationsResponseTypeDef = TypedDict(
@@ -829,22 +1002,49 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-ListVodSourcesRequestListVodSourcesPaginateTypeDef = TypedDict(
-    "ListVodSourcesRequestListVodSourcesPaginateTypeDef",
+_RequiredListVodSourcesRequestListVodSourcesPaginateTypeDef = TypedDict(
+    "_RequiredListVodSourcesRequestListVodSourcesPaginateTypeDef",
     {
         "SourceLocationName": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListVodSourcesRequestListVodSourcesPaginateTypeDef = TypedDict(
+    "_OptionalListVodSourcesRequestListVodSourcesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListVodSourcesRequestRequestTypeDef = TypedDict(
-    "ListVodSourcesRequestRequestTypeDef",
+
+class ListVodSourcesRequestListVodSourcesPaginateTypeDef(
+    _RequiredListVodSourcesRequestListVodSourcesPaginateTypeDef,
+    _OptionalListVodSourcesRequestListVodSourcesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListVodSourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListVodSourcesRequestRequestTypeDef",
     {
         "SourceLocationName": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListVodSourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListVodSourcesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListVodSourcesRequestRequestTypeDef(
+    _RequiredListVodSourcesRequestRequestTypeDef, _OptionalListVodSourcesRequestRequestTypeDef
+):
+    pass
+
 
 ListVodSourcesResponseTypeDef = TypedDict(
     "ListVodSourcesResponseTypeDef",
@@ -858,9 +1058,10 @@ ListVodSourcesResponseTypeDef = TypedDict(
 LivePreRollConfigurationTypeDef = TypedDict(
     "LivePreRollConfigurationTypeDef",
     {
-        "AdDecisionServerUrl": NotRequired[str],
-        "MaxDurationSeconds": NotRequired[int],
+        "AdDecisionServerUrl": str,
+        "MaxDurationSeconds": int,
     },
+    total=False,
 )
 
 LogConfigurationTypeDef = TypedDict(
@@ -873,73 +1074,113 @@ LogConfigurationTypeDef = TypedDict(
 ManifestProcessingRulesTypeDef = TypedDict(
     "ManifestProcessingRulesTypeDef",
     {
-        "AdMarkerPassthrough": NotRequired["AdMarkerPassthroughTypeDef"],
+        "AdMarkerPassthrough": "AdMarkerPassthroughTypeDef",
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PlaybackConfigurationTypeDef = TypedDict(
     "PlaybackConfigurationTypeDef",
     {
-        "AdDecisionServerUrl": NotRequired[str],
-        "AvailSuppression": NotRequired["AvailSuppressionTypeDef"],
-        "Bumper": NotRequired["BumperTypeDef"],
-        "CdnConfiguration": NotRequired["CdnConfigurationTypeDef"],
-        "ConfigurationAliases": NotRequired[Dict[str, Dict[str, str]]],
-        "DashConfiguration": NotRequired["DashConfigurationTypeDef"],
-        "HlsConfiguration": NotRequired["HlsConfigurationTypeDef"],
-        "LivePreRollConfiguration": NotRequired["LivePreRollConfigurationTypeDef"],
-        "LogConfiguration": NotRequired["LogConfigurationTypeDef"],
-        "ManifestProcessingRules": NotRequired["ManifestProcessingRulesTypeDef"],
-        "Name": NotRequired[str],
-        "PersonalizationThresholdSeconds": NotRequired[int],
-        "PlaybackConfigurationArn": NotRequired[str],
-        "PlaybackEndpointPrefix": NotRequired[str],
-        "SessionInitializationEndpointPrefix": NotRequired[str],
-        "SlateAdUrl": NotRequired[str],
-        "Tags": NotRequired[Dict[str, str]],
-        "TranscodeProfileName": NotRequired[str],
-        "VideoContentSourceUrl": NotRequired[str],
+        "AdDecisionServerUrl": str,
+        "AvailSuppression": "AvailSuppressionTypeDef",
+        "Bumper": "BumperTypeDef",
+        "CdnConfiguration": "CdnConfigurationTypeDef",
+        "ConfigurationAliases": Dict[str, Dict[str, str]],
+        "DashConfiguration": "DashConfigurationTypeDef",
+        "HlsConfiguration": "HlsConfigurationTypeDef",
+        "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "LogConfiguration": "LogConfigurationTypeDef",
+        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
+        "Name": str,
+        "PersonalizationThresholdSeconds": int,
+        "PlaybackConfigurationArn": str,
+        "PlaybackEndpointPrefix": str,
+        "SessionInitializationEndpointPrefix": str,
+        "SlateAdUrl": str,
+        "Tags": Dict[str, str],
+        "TranscodeProfileName": str,
+        "VideoContentSourceUrl": str,
     },
+    total=False,
 )
 
-PrefetchConsumptionTypeDef = TypedDict(
-    "PrefetchConsumptionTypeDef",
+_RequiredPrefetchConsumptionTypeDef = TypedDict(
+    "_RequiredPrefetchConsumptionTypeDef",
     {
         "EndTime": Union[datetime, str],
-        "AvailMatchingCriteria": NotRequired[Sequence["AvailMatchingCriteriaTypeDef"]],
-        "StartTime": NotRequired[Union[datetime, str]],
     },
 )
+_OptionalPrefetchConsumptionTypeDef = TypedDict(
+    "_OptionalPrefetchConsumptionTypeDef",
+    {
+        "AvailMatchingCriteria": Sequence["AvailMatchingCriteriaTypeDef"],
+        "StartTime": Union[datetime, str],
+    },
+    total=False,
+)
 
-PrefetchRetrievalTypeDef = TypedDict(
-    "PrefetchRetrievalTypeDef",
+
+class PrefetchConsumptionTypeDef(
+    _RequiredPrefetchConsumptionTypeDef, _OptionalPrefetchConsumptionTypeDef
+):
+    pass
+
+
+_RequiredPrefetchRetrievalTypeDef = TypedDict(
+    "_RequiredPrefetchRetrievalTypeDef",
     {
         "EndTime": Union[datetime, str],
-        "DynamicVariables": NotRequired[Mapping[str, str]],
-        "StartTime": NotRequired[Union[datetime, str]],
     },
 )
+_OptionalPrefetchRetrievalTypeDef = TypedDict(
+    "_OptionalPrefetchRetrievalTypeDef",
+    {
+        "DynamicVariables": Mapping[str, str],
+        "StartTime": Union[datetime, str],
+    },
+    total=False,
+)
 
-PrefetchScheduleTypeDef = TypedDict(
-    "PrefetchScheduleTypeDef",
+
+class PrefetchRetrievalTypeDef(
+    _RequiredPrefetchRetrievalTypeDef, _OptionalPrefetchRetrievalTypeDef
+):
+    pass
+
+
+_RequiredPrefetchScheduleTypeDef = TypedDict(
+    "_RequiredPrefetchScheduleTypeDef",
     {
         "Arn": str,
         "Consumption": "PrefetchConsumptionTypeDef",
         "Name": str,
         "PlaybackConfigurationName": str,
         "Retrieval": "PrefetchRetrievalTypeDef",
-        "StreamId": NotRequired[str],
     },
 )
+_OptionalPrefetchScheduleTypeDef = TypedDict(
+    "_OptionalPrefetchScheduleTypeDef",
+    {
+        "StreamId": str,
+    },
+    total=False,
+)
+
+
+class PrefetchScheduleTypeDef(_RequiredPrefetchScheduleTypeDef, _OptionalPrefetchScheduleTypeDef):
+    pass
+
 
 PutChannelPolicyRequestRequestTypeDef = TypedDict(
     "PutChannelPolicyRequestRequestTypeDef",
@@ -952,21 +1193,22 @@ PutChannelPolicyRequestRequestTypeDef = TypedDict(
 PutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
     "PutPlaybackConfigurationRequestRequestTypeDef",
     {
-        "AdDecisionServerUrl": NotRequired[str],
-        "AvailSuppression": NotRequired["AvailSuppressionTypeDef"],
-        "Bumper": NotRequired["BumperTypeDef"],
-        "CdnConfiguration": NotRequired["CdnConfigurationTypeDef"],
-        "ConfigurationAliases": NotRequired[Mapping[str, Mapping[str, str]]],
-        "DashConfiguration": NotRequired["DashConfigurationForPutTypeDef"],
-        "LivePreRollConfiguration": NotRequired["LivePreRollConfigurationTypeDef"],
-        "ManifestProcessingRules": NotRequired["ManifestProcessingRulesTypeDef"],
-        "Name": NotRequired[str],
-        "PersonalizationThresholdSeconds": NotRequired[int],
-        "SlateAdUrl": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
-        "TranscodeProfileName": NotRequired[str],
-        "VideoContentSourceUrl": NotRequired[str],
+        "AdDecisionServerUrl": str,
+        "AvailSuppression": "AvailSuppressionTypeDef",
+        "Bumper": "BumperTypeDef",
+        "CdnConfiguration": "CdnConfigurationTypeDef",
+        "ConfigurationAliases": Mapping[str, Mapping[str, str]],
+        "DashConfiguration": "DashConfigurationForPutTypeDef",
+        "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
+        "Name": str,
+        "PersonalizationThresholdSeconds": int,
+        "SlateAdUrl": str,
+        "Tags": Mapping[str, str],
+        "TranscodeProfileName": str,
+        "VideoContentSourceUrl": str,
     },
+    total=False,
 )
 
 PutPlaybackConfigurationResponseTypeDef = TypedDict(
@@ -995,15 +1237,28 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
     },
 )
 
-RequestOutputItemTypeDef = TypedDict(
-    "RequestOutputItemTypeDef",
+_RequiredRequestOutputItemTypeDef = TypedDict(
+    "_RequiredRequestOutputItemTypeDef",
     {
         "ManifestName": str,
         "SourceGroup": str,
-        "DashPlaylistSettings": NotRequired["DashPlaylistSettingsTypeDef"],
-        "HlsPlaylistSettings": NotRequired["HlsPlaylistSettingsTypeDef"],
     },
 )
+_OptionalRequestOutputItemTypeDef = TypedDict(
+    "_OptionalRequestOutputItemTypeDef",
+    {
+        "DashPlaylistSettings": "DashPlaylistSettingsTypeDef",
+        "HlsPlaylistSettings": "HlsPlaylistSettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class RequestOutputItemTypeDef(
+    _RequiredRequestOutputItemTypeDef, _OptionalRequestOutputItemTypeDef
+):
+    pass
+
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -1016,25 +1271,39 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-ResponseOutputItemTypeDef = TypedDict(
-    "ResponseOutputItemTypeDef",
+_RequiredResponseOutputItemTypeDef = TypedDict(
+    "_RequiredResponseOutputItemTypeDef",
     {
         "ManifestName": str,
         "PlaybackUrl": str,
         "SourceGroup": str,
-        "DashPlaylistSettings": NotRequired["DashPlaylistSettingsTypeDef"],
-        "HlsPlaylistSettings": NotRequired["HlsPlaylistSettingsTypeDef"],
     },
 )
+_OptionalResponseOutputItemTypeDef = TypedDict(
+    "_OptionalResponseOutputItemTypeDef",
+    {
+        "DashPlaylistSettings": "DashPlaylistSettingsTypeDef",
+        "HlsPlaylistSettings": "HlsPlaylistSettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class ResponseOutputItemTypeDef(
+    _RequiredResponseOutputItemTypeDef, _OptionalResponseOutputItemTypeDef
+):
+    pass
+
 
 ScheduleAdBreakTypeDef = TypedDict(
     "ScheduleAdBreakTypeDef",
     {
-        "ApproximateDurationSeconds": NotRequired[int],
-        "ApproximateStartTime": NotRequired[datetime],
-        "SourceLocationName": NotRequired[str],
-        "VodSourceName": NotRequired[str],
+        "ApproximateDurationSeconds": int,
+        "ApproximateStartTime": datetime,
+        "SourceLocationName": str,
+        "VodSourceName": str,
     },
+    total=False,
 )
 
 ScheduleConfigurationTypeDef = TypedDict(
@@ -1044,71 +1313,95 @@ ScheduleConfigurationTypeDef = TypedDict(
     },
 )
 
-ScheduleEntryTypeDef = TypedDict(
-    "ScheduleEntryTypeDef",
+_RequiredScheduleEntryTypeDef = TypedDict(
+    "_RequiredScheduleEntryTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
         "ProgramName": str,
         "SourceLocationName": str,
         "VodSourceName": str,
-        "ApproximateDurationSeconds": NotRequired[int],
-        "ApproximateStartTime": NotRequired[datetime],
-        "ScheduleAdBreaks": NotRequired[List["ScheduleAdBreakTypeDef"]],
-        "ScheduleEntryType": NotRequired[ScheduleEntryTypeType],
     },
 )
+_OptionalScheduleEntryTypeDef = TypedDict(
+    "_OptionalScheduleEntryTypeDef",
+    {
+        "ApproximateDurationSeconds": int,
+        "ApproximateStartTime": datetime,
+        "ScheduleAdBreaks": List["ScheduleAdBreakTypeDef"],
+        "ScheduleEntryType": ScheduleEntryTypeType,
+    },
+    total=False,
+)
+
+
+class ScheduleEntryTypeDef(_RequiredScheduleEntryTypeDef, _OptionalScheduleEntryTypeDef):
+    pass
+
 
 SecretsManagerAccessTokenConfigurationTypeDef = TypedDict(
     "SecretsManagerAccessTokenConfigurationTypeDef",
     {
-        "HeaderName": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "SecretStringKey": NotRequired[str],
+        "HeaderName": str,
+        "SecretArn": str,
+        "SecretStringKey": str,
     },
+    total=False,
 )
 
 SegmentDeliveryConfigurationTypeDef = TypedDict(
     "SegmentDeliveryConfigurationTypeDef",
     {
-        "BaseUrl": NotRequired[str],
-        "Name": NotRequired[str],
+        "BaseUrl": str,
+        "Name": str,
     },
+    total=False,
 )
 
 SlateSourceTypeDef = TypedDict(
     "SlateSourceTypeDef",
     {
-        "SourceLocationName": NotRequired[str],
-        "VodSourceName": NotRequired[str],
+        "SourceLocationName": str,
+        "VodSourceName": str,
     },
+    total=False,
 )
 
-SourceLocationTypeDef = TypedDict(
-    "SourceLocationTypeDef",
+_RequiredSourceLocationTypeDef = TypedDict(
+    "_RequiredSourceLocationTypeDef",
     {
         "Arn": str,
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
-        "AccessConfiguration": NotRequired["AccessConfigurationTypeDef"],
-        "CreationTime": NotRequired[datetime],
-        "DefaultSegmentDeliveryConfiguration": NotRequired[
-            "DefaultSegmentDeliveryConfigurationTypeDef"
-        ],
-        "LastModifiedTime": NotRequired[datetime],
-        "SegmentDeliveryConfigurations": NotRequired[List["SegmentDeliveryConfigurationTypeDef"]],
-        "Tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalSourceLocationTypeDef = TypedDict(
+    "_OptionalSourceLocationTypeDef",
+    {
+        "AccessConfiguration": "AccessConfigurationTypeDef",
+        "CreationTime": datetime,
+        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
+        "LastModifiedTime": datetime,
+        "SegmentDeliveryConfigurations": List["SegmentDeliveryConfigurationTypeDef"],
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class SourceLocationTypeDef(_RequiredSourceLocationTypeDef, _OptionalSourceLocationTypeDef):
+    pass
+
 
 SpliceInsertMessageTypeDef = TypedDict(
     "SpliceInsertMessageTypeDef",
     {
-        "AvailNum": NotRequired[int],
-        "AvailsExpected": NotRequired[int],
-        "SpliceEventId": NotRequired[int],
-        "UniqueProgramId": NotRequired[int],
+        "AvailNum": int,
+        "AvailsExpected": int,
+        "SpliceEventId": int,
+        "UniqueProgramId": int,
     },
+    total=False,
 )
 
 StartChannelRequestRequestTypeDef = TypedDict(
@@ -1133,15 +1426,26 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-TransitionTypeDef = TypedDict(
-    "TransitionTypeDef",
+_RequiredTransitionTypeDef = TypedDict(
+    "_RequiredTransitionTypeDef",
     {
         "RelativePosition": RelativePositionType,
         "Type": str,
-        "RelativeProgram": NotRequired[str],
-        "ScheduledStartTimeMillis": NotRequired[int],
     },
 )
+_OptionalTransitionTypeDef = TypedDict(
+    "_OptionalTransitionTypeDef",
+    {
+        "RelativeProgram": str,
+        "ScheduledStartTimeMillis": int,
+    },
+    total=False,
+)
+
+
+class TransitionTypeDef(_RequiredTransitionTypeDef, _OptionalTransitionTypeDef):
+    pass
+
 
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
@@ -1151,14 +1455,27 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateChannelRequestRequestTypeDef = TypedDict(
-    "UpdateChannelRequestRequestTypeDef",
+_RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Outputs": Sequence["RequestOutputItemTypeDef"],
-        "FillerSlate": NotRequired["SlateSourceTypeDef"],
     },
 )
+_OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChannelRequestRequestTypeDef",
+    {
+        "FillerSlate": "SlateSourceTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateChannelRequestRequestTypeDef(
+    _RequiredUpdateChannelRequestRequestTypeDef, _OptionalUpdateChannelRequestRequestTypeDef
+):
+    pass
+
 
 UpdateChannelResponseTypeDef = TypedDict(
     "UpdateChannelResponseTypeDef",
@@ -1176,20 +1493,30 @@ UpdateChannelResponseTypeDef = TypedDict(
     },
 )
 
-UpdateSourceLocationRequestRequestTypeDef = TypedDict(
-    "UpdateSourceLocationRequestRequestTypeDef",
+_RequiredUpdateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateSourceLocationRequestRequestTypeDef",
     {
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
-        "AccessConfiguration": NotRequired["AccessConfigurationTypeDef"],
-        "DefaultSegmentDeliveryConfiguration": NotRequired[
-            "DefaultSegmentDeliveryConfigurationTypeDef"
-        ],
-        "SegmentDeliveryConfigurations": NotRequired[
-            Sequence["SegmentDeliveryConfigurationTypeDef"]
-        ],
     },
 )
+_OptionalUpdateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateSourceLocationRequestRequestTypeDef",
+    {
+        "AccessConfiguration": "AccessConfigurationTypeDef",
+        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
+        "SegmentDeliveryConfigurations": Sequence["SegmentDeliveryConfigurationTypeDef"],
+    },
+    total=False,
+)
+
+
+class UpdateSourceLocationRequestRequestTypeDef(
+    _RequiredUpdateSourceLocationRequestRequestTypeDef,
+    _OptionalUpdateSourceLocationRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateSourceLocationResponseTypeDef = TypedDict(
     "UpdateSourceLocationResponseTypeDef",
@@ -1230,15 +1557,25 @@ UpdateVodSourceResponseTypeDef = TypedDict(
     },
 )
 
-VodSourceTypeDef = TypedDict(
-    "VodSourceTypeDef",
+_RequiredVodSourceTypeDef = TypedDict(
+    "_RequiredVodSourceTypeDef",
     {
         "Arn": str,
         "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
         "VodSourceName": str,
-        "CreationTime": NotRequired[datetime],
-        "LastModifiedTime": NotRequired[datetime],
-        "Tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalVodSourceTypeDef = TypedDict(
+    "_OptionalVodSourceTypeDef",
+    {
+        "CreationTime": datetime,
+        "LastModifiedTime": datetime,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class VodSourceTypeDef(_RequiredVodSourceTypeDef, _OptionalVodSourceTypeDef):
+    pass
